summaryrefslogtreecommitdiff
path: root/ACEXML/common/StrCharStream.h
diff options
context:
space:
mode:
authorkitty <kitty@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2003-05-30 03:31:49 +0000
committerkitty <kitty@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>2003-05-30 03:31:49 +0000
commitaa3cd957b6af79cc8b48c8d0ce8bde233af436fe (patch)
treeeb96ffb2db36d1e7a74345f2a7828a84c64ca208 /ACEXML/common/StrCharStream.h
parent240eac73f8c3d9d3f053fb85aa309dcd9a0326ef (diff)
downloadATCD-aa3cd957b6af79cc8b48c8d0ce8bde233af436fe.tar.gz
ChangeLogTag: Thu May 29 22:03:40 2003 Krishnakumar B <kitty@spam.invalid.domain>
Diffstat (limited to 'ACEXML/common/StrCharStream.h')
-rw-r--r--ACEXML/common/StrCharStream.h16
1 files changed, 9 insertions, 7 deletions
diff --git a/ACEXML/common/StrCharStream.h b/ACEXML/common/StrCharStream.h
index 6321decb9a2..08b7bdbef9b 100644
--- a/ACEXML/common/StrCharStream.h
+++ b/ACEXML/common/StrCharStream.h
@@ -34,14 +34,11 @@ public:
/// Default constructor.
ACEXML_StrCharStream (void);
- /// Initializing Constructor.
- ACEXML_StrCharStream (const ACEXML_Char *str);
-
/// Destructor
virtual ~ACEXML_StrCharStream (void);
- /// Initializing and reset the StrCharStream with @a str.
- int open (const ACEXML_Char *str);
+ /// Initializing StrCharStream with @a str and @a name
+ int open (const ACEXML_Char *str, const ACEXML_Char* name);
/**
* Returns the available ACEXML_Char in the buffer. -1
@@ -68,8 +65,7 @@ public:
/**
* Read the next batch of ACEXML_Char strings
*/
- virtual int read (ACEXML_Char *str,
- size_t len);
+ virtual int read (ACEXML_Char *str, size_t len);
/**
* Peek the next ACEXML_Char in the CharStream. Return the
@@ -82,6 +78,11 @@ public:
*/
virtual const ACEXML_Char *getEncoding (void);
+ /*
+ * Get the systemId for the underlying CharStream
+ */
+ virtual const ACEXML_Char* getSystemId (void);
+
/**
* Resets the pointer to the beginning of the stream.
*/
@@ -92,6 +93,7 @@ private:
ACEXML_Char *ptr_;
ACEXML_Char *end_;
ACEXML_Char* encoding_;
+ ACEXML_Char* name_;
};